package main

import (
	"context"
	"fmt"
	"net"
	"time"

	"gitlab.mashroom.com/mashroom/backend/common/api/health"
	"gitlab.mashroom.com/mashroom/backend/common/generic/addr"
	"gitlab.mashroom.com/mashroom/backend/common/generic/grpc"
	"gitlab.mashroom.com/mashroom/backend/common/generic/log"
	"gitlab.mashroom.com/mashroom/backend/gmailparser/impl"
	"gitlab.mashroom.com/mashroom/backend/gmailparser/version"
)

func main() {
	if listener, err := net.Listen("tcp", addr.Grpc); err != nil {
		panic(err)
	} else {
		grpcServer, err := grpc.NewServer("gmailparser")
		if err != nil {
			panic(err)
		}
		healthServer := version.NewHealthServer()
		health.RegisterHealthServiceServer(grpcServer, healthServer)

		impl.GmailSubscribe(context.Background())
		go impl.GmailSync(context.Background())
		log.Info("gmailparser started")
		UpdatingSub()
		_ = grpcServer.Serve(listener)
	}
}

func UpdatingSub() {
	fmt.Println("UpdatingSub start")

	go func() {
		time.Sleep(time.Hour * 12)
		for {
			fmt.Println("GoFunc start")
			impl.GmailSubscribe(context.Background())
			impl.GmailSync(context.Background())
			fmt.Println("GoFunc stop")
			time.Sleep(time.Hour * 12)
		}
	}()
}
